<?php

namespace Drupal\eca_content\Plugin\Action;

use Drupal\Core\Form\FormStateInterface;
use Drupal\eca\Plugin\Action\ConfigurableActionBase;

/**
 * Load referenced entity into token environment.
 *
 * @Action(
 *   id = "eca_token_load_entity_ref",
 *   label = @Translation("Token: load referenced entity"),
 *   type = "entity"
 * )
 */
class TokenLoadEntityRef extends ConfigurableActionBase {

  /**
   * {@inheritdoc}
   */
  public function execute($entity = NULL): void {
    if ($entity === NULL) {
      return;
    }
    /** @var \Drupal\Core\Entity\ContentEntityInterface $entity */
    if (!$entity->hasField($this->configuration['field_name_entity_ref'])) {
      // TODO: Log this error.
      return;
    }
    if ($referencedEntity = $entity->get($this->configuration['field_name_entity_ref'])->first()->get('entity')->getTarget()->getValue()) {
      $this->tokenServices->addTokenData($referencedEntity->getEntityTypeId(), $referencedEntity);
    }
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration(): array {
    return [
        'field_name_entity_ref' => '',
      ] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state): array {
    $form['field_name_entity_ref'] = [
      '#type' => 'textfield',
      '#title' => t('Field name entity reference'),
      '#default_value' => $this->configuration['field_name_entity_ref'],
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state): void {
    $this->configuration['field_name_entity_ref'] = $form_state->getValue('field_name_entity_ref');
  }

}
