<?php

namespace Drupal\eca_content\Plugin\ECA\Condition;

use Drupal\Core\Entity\FieldableEntityInterface;
use Drupal\eca\Annotation\EcaCondition;
use Drupal\eca\Plugin\ECA\Condition\BaseStringComparison;

/**
 * Plugin implementation of the ECA condition for an entity field value.
 *
 * @EcaCondition(
 *   id = "entity_field_value",
 *   label = "Entity field value"
 * )
 */
class EntityFieldValue extends BaseStringComparison {

  /**
   * {@inheritdoc}
   */
  protected function getFirstValue(): string {
    if (isset($this->arguments['entity'])) {
      $entity = $this->arguments['entity'];
      if ($entity instanceof FieldableEntityInterface && $entity->hasField($this->configuration['field_name'])) {
        return $entity->get($this->configuration['field_name'])->getValue();
      }
    }
    return '';
  }

  /**
   * {@inheritdoc}
   */
  protected function getSecondValue(): string {
    return $this->configuration['field_value'];
  }

  /**
   * {@inheritdoc}
   */
  public function fields(): array {
    $fields = parent::fields();
    $fields[] = [
      'name' => 'field_name',
      'label' => 'Field name',
      'type' => 'String',
    ];
    $fields[] = [
      'name' => 'field_value',
      'label' => 'Value',
      'type' => 'String',
    ];
    return $fields;
  }

}
