<?php

namespace Drupal\eca_content\Plugin\ECA\Condition;

use Drupal\Core\Entity\FieldableEntityInterface;
use Drupal\eca\Annotation\EcaCondition;
use Drupal\eca\PluginConditionBase;

/**
 * Plugin implementation of the ECA condition for changed entity field value.
 *
 * @EcaCondition(
 *   id = "entity_field_value_changed",
 *   label = "Entity field value changed"
 * )
 */
class EntityFieldValueChanged extends PluginConditionBase {

  /**
   * {@inheritdoc}
   */
  public function assertConditions(): bool {
    if (isset($this->arguments['entity'])) {
      $entity = $this->arguments['entity'];
      if ($entity instanceof FieldableEntityInterface && isset($entity->original) && $entity->hasField($this->configuration['field_name'])) {
        return $entity->get($this->configuration['field_name'])->getValue() !== $entity->original->get($this->configuration['field_name'])->getValue();
      }
    }
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function fields(): array {
    $fields = parent::fields();
    $fields[] = [
      'name' => 'field_name',
      'label' => 'Field name',
      'type' => 'String',
    ];
    return $fields;
  }

}
