<?php

namespace Drupal\eca_content\Plugin\ECA\Condition;

use Drupal\Core\Entity\EntityInterface;
use Drupal\eca\Annotation\EcaCondition;
use Drupal\eca\PluginConditionBase;

/**
 * Plugin implementation of the ECA condition for entity type and bundle.
 *
 * @EcaCondition(
 *   id = "entity_type_bundle",
 *   label = "Entity type and bundle"
 * )
 */
class EntityTypeAndBundle extends PluginConditionBase {

  /**
   * {@inheritdoc}
   */
  public function assertConditions(): bool {
    if (isset($this->arguments['entity'])) {
      $entity = $this->arguments['entity'];
      if ($entity instanceof EntityInterface) {
        [$type, $bundle] = explode(' ', $this->configuration['type']);
        if ($bundle === 'any') {
          return $entity->getEntityTypeId() === $type;
        }
        return $entity->getEntityTypeId() === $type && $entity->bundle() === $bundle;
      }
    }
    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function fields(): array {
    $types = [];
    foreach ($this->entityTypeManager->getDefinitions() as $definition) {
      $types[] = [
        'name' => $definition->getLabel(),
        'value' => $definition->id() . ' ' . 'any',
      ];
      foreach ($this->entityTypeBundleInfo->getBundleInfo($definition->id()) as $bundle => $bundleDef) {
        $types[] = [
          'name' => $definition->getLabel() . ': ' . $bundleDef['label'],
          'value' => $definition->id() . ' ' . $bundle,
        ];
      }
    }

    $fields = parent::fields();
    $fields[] = [
      'name' => 'type',
      'label' => 'Type (and bundle)',
      'type' => 'Dropdown',
      'extras' => [
        'choices' => $types,
      ],
    ];
    return $fields;
  }

}
