<?php

namespace Drupal\eca_content\Plugin\ECA\Event;

use Drupal;
use Drupal\Component\Plugin\Derivative\DeriverBase;
use Drupal\Core\Entity\ContentEntityTypeInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;

class ContentEntityEventDeriver extends DeriverBase {

  use StringTranslationTrait;

  /**
   * @param array $base_plugin_definition
   * @param string $action_id
   * @param array $action
   * @param string $entity_type_id
   * @param string|null $entity_label
   */
  private function addDerivate(array $base_plugin_definition, string $action_id, array $action, string $entity_type_id = '', string $entity_label = NULL): void {
    $id = empty($entity_type_id) ? $action_id : implode('_', [$action_id, $entity_type_id]);
    $this->derivatives[$id] = [
      'drupal_id' => $action['drupal_id'],
      'drupal_event_class' => $action['drupal_event_class'],
      'entity_type_id' => $entity_type_id,
      'action' => $action_id,
      'label' => $entity_label === NULL ?
        $action['label'] . ' any content entity' :
        $action['label'] . ' content entity of type ' . $entity_label,
    ] + $base_plugin_definition;
  }

  /**
   * {@inheritdoc}
   */
  public function getDerivativeDefinitions($base_plugin_definition): array {
    $actions = ContentEntityEvent::actions();
    $this->derivatives = [];

    foreach ($actions as $action_id => $action) {
      $this->addDerivate($base_plugin_definition, $action_id, $action);
      foreach (Drupal::entityTypeManager()->getDefinitions() as $definition) {
        if ($definition instanceof ContentEntityTypeInterface) {
          $this->addDerivate($base_plugin_definition, $action_id, $action, $definition->id(), $definition->getLabel());
        }
      }
    }

    return $this->derivatives;
  }

}
