<?php

namespace Drupal\eca_user\Plugin\ECA\Condition;

use Drupal\eca\Annotation\EcaCondition;
use Drupal\user\Entity\Role;

/**
 * Plugin implementation of the ECA condition of the current user's role.
 *
 * @EcaCondition(
 *   id = "current_user_role",
 *   label = "Role of current user"
 * )
 */
class CurrentUserRole extends BaseUser {

  /**
   * {@inheritdoc}
   */
  public function assertConditions(): bool {
    $userRoles = $this->currentUser->getRoles();
    return in_array($this->configuration['role'], $userRoles, TRUE);
  }

  /**
   * {@inheritdoc}
   */
  public function fields(): array {
    $roles = [];
    /** @var \Drupal\user\RoleInterface $role */
    foreach (Role::loadMultiple() as $role) {
      $roles[] = [
        'name' => $role->label(),
        'value' => $role->id(),
      ];
    }

    $fields = parent::fields();
    $fields[] = [
      'name' => 'role',
      'label' => 'Role',
      'type' => 'Dropdown',
      'extras' => [
        'choices' => $roles,
      ],
    ];
    return $fields;
  }

}
