<?php

namespace Drupal\eca;

use Drupal\Component\Plugin\Exception\PluginException;
use Drupal\Core\Action\ActionInterface;
use Drupal\Core\Action\ActionManager;

class ActionServices {

  use PluginTrait;

  /**
   * @var \Drupal\Core\Action\ActionManager
   */
  protected ActionManager $actionManager;

  /**
   * Processor constructor.
   *
   * @param \Drupal\Core\Action\ActionManager $action_manager
   */
  public function __construct(ActionManager $action_manager) {
    $this->actionManager = $action_manager;
  }

  /**
   * @return \Drupal\Core\Action\ActionInterface[]
   */
  public function actions(): array {
    static $actions;
    if ($actions === NULL) {
      $actions = [];
      foreach ($this->actionManager->getDefinitions() as $plugin_id => $definition) {
        try {
          $actions[] = $this->actionManager->createInstance($plugin_id);
        } catch (PluginException $e) {
          // Can be ignored.
        }
      }
    }
    $this->sortPlugins($actions);
    return $actions;
  }

  /**
   * @param \Drupal\Core\Action\ActionInterface $action
   *
   * @return array
   */
  public function fields(ActionInterface $action): array {
    $fields = [];
    if (method_exists($action, 'defaultConfiguration') && $config = $action->defaultConfiguration()) {
      foreach ($config as $key => $value) {
        if (is_bool($value)) {
          $fields[] = PluginConditionBase::checkbox($key, $key, $value);
          continue;
        }
        if (is_array($value)) {
          $value = implode(',', $value);
        }
        $fields[] = [
          'name' => $key,
          'label' => $key,
          'type' => 'String',
          'value' => $value,
        ];
      }
    }
    return $fields;
  }

}
