<?php

namespace Drupal\eca\Commands;

use Drupal\eca\ModelerServices;
use Drush\Commands\DrushCommands;

/**
 * A Drush commandfile.
 */
class EcaCommands extends DrushCommands {

  /**
   * @var \Drupal\eca\ModelerServices
   */
  protected ModelerServices $modelerServices;

  /**
   * EcaCommands constructor.
   *
   */
  public function __construct(ModelerServices $modeler_services) {
    parent::__construct();
    $this->modelerServices = $modeler_services;
  }

  /**
   * Import a single ECA file.
   *
   * @usage eca:import
   *   Import a single ECA file.
   *
   * @param string $plugin_id
   *   The id of the modeler plugin.
   * @param string $filename
   *   The file name to import, relative to the Drupal root or absolute.
   *
   * @command eca:import
   */
  public function import(string $plugin_id, string $filename): void {
    $modeler = $this->modelerServices->getModeler($plugin_id);
    if ($modeler === NULL) {
      $this->io()->error('This modeler plugin does not exist.');
      return;
    }
    if (!file_exists($filename)) {
      $this->io()->error('This file does not exist.');
      return;
    }
    $modeler->load(file_get_contents($filename));
    $this->modelerServices->import($modeler, $filename);
  }

  /**
   * Update all previously imported ECA files.
   *
   * @usage eca:update
   *   Update all previously imported ECA files.
   *
   * @command eca:update
   */
  public function updateAll(): void {
    $this->modelerServices->updateAll();
  }

  /**
   * Export components for all ECA modelers.
   *
   * @command eca:export
   */
  public function export(): void {
    $this->modelerServices->export();
  }

}
