<?php

namespace Drupal\eca\Controller;

use Drupal\Core\Ajax\AjaxResponse;
use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Entity\EntityStorageInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Link;
use Drupal\Core\Url;
use Drupal\eca\ModelerServices;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\Request;

/**
 * Class Eca.
 *
 * @package Drupal\eca\Controller
 */
class Eca extends ControllerBase {

  /**
   * @var \Symfony\Component\HttpFoundation\Request
   */
  protected Request $request;

  /**
   * @var \Drupal\eca\ModelerServices
   */
  protected ModelerServices $modelerServices;

  /**
   * @var \Drupal\Core\Entity\EntityStorageInterface
   */
  protected EntityStorageInterface $storage;

  /**
   * BpmnIo constructor.
   *
   * @param \Symfony\Component\HttpFoundation\Request $request
   * @param \Drupal\eca\ModelerServices $modeler_services
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   */
  public function __construct(Request $request, ModelerServices $modeler_services, EntityTypeManagerInterface $entity_type_manager) {
    $this->request = $request;
    $this->modelerServices = $modeler_services;
    $this->storage = $entity_type_manager->getStorage('eca');
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): Eca {
    return new static(
      $container->get('request_stack')->getCurrentRequest(),
      $container->get('eca.service.modeler'),
      $container->get('entity_type.manager')
    );
  }

  public function list(): array {
    $rows = [];
    /** @var \Drupal\eca\Entity\Eca $eca */
    foreach ($this->storage->loadMultiple() as $eca) {
      $row = [
        'label' => $eca->isEditable() ?
          Link::fromTextAndUrl($eca->label(), Url::fromRoute('eca.edit', ['eca' => $eca->id()])) :
          $eca->label(),
        'modeler' => $eca->get('modeler'),
        'id' => $eca->id(),
        'version' => $eca->get('version'),
        'status' => $eca->status() ? $this->t('yes') : $this->t('no'),
      ];
      $rows[] = $row;
    }
    return [
      '#type' => 'table',
      '#header' => [
        'label' => $this->t('Label'),
        'modeler' => $this->t('Modeler'),
        'id' => $this->t('ID'),
        'version' => $this->t('Version'),
        'status' => $this->t('Executable'),
      ],
      '#title' => $this->t('ECA Models'),
      '#rows' => $rows,
      '#empty' => $this->t('There are no ECA yet.'),
    ];
  }

  public function edit(string $eca): array {
    /** @var \Drupal\eca\Entity\Eca $config */
    if (($config = $this->storage->load($eca)) && $config->isEditable()) {
      $bpmnXml = $config->get('filename');
      $build = $config->getModeler()->edit($eca, $bpmnXml);
      $build['#title'] = $this->t('ECA Model: %label', ['%label' => $config->label()]);
      return $build;
    }
    return [];
  }

  public function save(string $modeler_id): AjaxResponse {
    if (($modeler = $this->modelerServices->getModeler($modeler_id)) && $modeler->isEditable()) {
      $xml = $this->request->getContent();
      $modeler->load($xml);
      $this->modelerServices->import($modeler, $xml);
    }
    return new AjaxResponse();
  }

}
