<?php

namespace Drupal\eca\Entity\Objects;

use Drupal\eca\PluginEventInterface;
use Drupal\eca\Entity\Eca;

class EcaEvent extends EcaObject {

  /**
   * @var \Drupal\eca\PluginEventInterface
   */
  protected PluginEventInterface $plugin;

  /**
   * @var array
   */
  protected array $variables = [];

  /**
   * Event constructor.
   *
   * @param \Drupal\eca\Entity\Eca $eca
   * @param string $id
   * @param \Drupal\eca\PluginEventInterface $plugin
   */
  public function __construct(Eca $eca, string $id, PluginEventInterface $plugin) {
    parent::__construct($eca, $id, $this);
    $this->plugin = $plugin;
  }

  /**
   * @param \Symfony\Contracts\EventDispatcher\Event|\Symfony\Component\EventDispatcher\Event $event
   *
   * @return bool
   */
  public function applies($event): bool {
    /** @noinspection NotOptimalIfConditionsInspection */
    if (get_class($event) === $this->plugin->drupalEventClass() && $this->plugin->applies($event, $this->configuration)) {
      $this->addVariables($this->plugin->output($event));
      return TRUE;
    }
    return FALSE;
  }

  /**
   * @param string $key
   * @param mixed $value
   */
  public function addVariable(string $key, $value): void {
    $this->variables[$key] = $value;
  }

  /**
   * @return array
   */
  public function getVariables(): array {
    return $this->variables;
  }

}
