<?php

namespace Drupal\eca\Entity\Objects;

use Drupal\eca\Entity\Eca;

abstract class EcaObject {

  /**
   * @var \Drupal\eca\Entity\Eca
   */
  protected Eca $eca;

  /**
   * @var \Drupal\eca\Entity\Objects\EcaEvent
   */
  protected EcaEvent $event;

  /**
   * @var array
   */
  protected array $configuration = [];

  /**
   * @var array
   */
  protected array $successors = [];

  /**
   * @var string
   */
  protected string $id;

  /**
   * Constructor.
   *
   * @param \Drupal\eca\Entity\Eca $eca
   * @param string $id
   */
  public function __construct(Eca $eca, string $id, EcaEvent $event) {
    $this->eca = $eca;
    $this->id = $id;
    $this->event = $event;
  }

  /**
   * @return \Drupal\eca\Entity\Objects\EcaEvent
   */
  public function getEvent(): EcaEvent {
    return $this->event;
  }

  /**
   * @param string $key
   * @param mixed $value
   *
   * @return $this
   */
  public function setConfiguration(string $key, $value): EcaObject {
    $this->configuration[$key] = $value;
    return $this;
  }

  /**
   * @param array $successors
   *
   * @return $this
   */
  public function setSuccessors(array $successors): EcaObject {
    $this->successors = $successors;
    return $this;
  }

  /**
   * @return array
   */
  public function getSuccessors(): array {
    return $this->successors;
  }

  /**
   * @return string
   */
  public function getId(): string {
    return $this->id;
  }

  /**
   * @param array $values
   *
   * @return \Drupal\eca\Entity\Objects\EcaObject
   */
  public function addVariables(array $values): EcaObject {
    foreach ($values as $key => $value) {
      $this->event->addVariable($key, $value);
    }
    return $this;
  }

  /**
   * @return array
   */
  public function getVariables(): array {
    return $this->event->getVariables();
  }

  /**
   * @param \Drupal\eca\Entity\Objects\EcaObject $predecessor
   * @param \Symfony\Contracts\EventDispatcher\Event|\Symfony\Component\EventDispatcher\Event $event
   *
   * @return bool
   */
  public function execute(EcaObject $predecessor, $event): bool {
    return TRUE;
  }

}
