<?php

namespace Drupal\eca\EventSubscriber;

use Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException;
use Drupal\Component\Plugin\Exception\PluginNotFoundException;
use Drupal\eca\Plugin\ECA\Event\ConfigEvent;
use Drupal\eca\Plugin\ECA\Event\DrupalCoreEvent;
use Drupal\eca\Plugin\ECA\Event\KernelEvent;
use Drupal\eca\Plugin\ECA\Event\RoutingEvent;
use Drupal\eca\Processor;
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

/**
 * ECA event subscriber.
 */
class Eca implements EventSubscriberInterface {

  /**
   * @var \Drupal\eca\Processor
   */
  protected Processor $processor;

  /**
   * ContentEntity constructor.
   *
   * @param \Drupal\eca\Processor $processor
   */
  public function __construct(Processor $processor) {
    $this->processor = $processor;
  }

  /**
   * @param \Symfony\Contracts\EventDispatcher\Event|\Symfony\Component\EventDispatcher\Event $event
   */
  public function onEvent($event): void {
    try {
      $this->processor->execute($event);
    }
    catch (InvalidPluginDefinitionException | PluginNotFoundException $e) {
      // This is thrown during installation of eca and we can ignore this.
    }
  }

  /**
   * {@inheritdoc}
   */
  public static function getSubscribedEvents(): array {
    $events = [];
    foreach (ConfigEvent::actions() as $action) {
      $events[$action['drupal_id']][] = ['onEvent'];
    }
    foreach (DrupalCoreEvent::actions() as $action) {
      $events[$action['drupal_id']][] = ['onEvent'];
    }
    foreach (KernelEvent::actions() as $action) {
      $events[$action['drupal_id']][] = ['onEvent'];
    }
    foreach (RoutingEvent::actions() as $action) {
      $events[$action['drupal_id']][] = ['onEvent'];
    }
    return $events;
  }

}
