<?php

namespace Drupal\eca\Plugin\Action;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Element;
use Drupal\eca\Event\FormBase;
use Drupal\eca\PluginConditionBase;

/**
 * Require a form field.
 *
 * @Action(
 *   id = "eca_form_field_require",
 *   label = @Translation("Form field: require")
 * )
 */
class FormFieldRequire extends FormFieldActionBase {

  protected function setRequired(array &$element, bool $flag): void {
    foreach (Element::children($element, TRUE) as $key) {
      if (isset($element[$key]) && $element[$key]) {
        $this->setRequired($element[$key], $flag);
      }
    }
    $element['#required'] = $flag;
    if (!$flag && isset($element['#type']) && $element['#type'] === 'textfield' && $element['#default_value'] === NULL) {
      $element['#default_value'] = '-';
    }
  }

  /**
   * {@inheritdoc}
   */
  public function execute(): void {
    if ($this->event instanceof FormBase) {
      $form_state = $this->event->getFormState();
      if (!$form_state->isProcessingInput()) {
        $form = $this->event->getForm();
        $this->setRequired($form[$this->configuration['field_name']], ($this->configuration['flag'] === PluginConditionBase::OPTION_YES));
        $this->event->setForm($form);
      }
    }
  }

  /**
   * {@inheritdoc}
   */
  public function defaultConfiguration(): array {
    return [
      'flag' => TRUE,
    ] + parent::defaultConfiguration();
  }

  /**
   * {@inheritdoc}
   */
  public function buildConfigurationForm(array $form, FormStateInterface $form_state): array {
    parent::buildConfigurationForm($form, $form_state);
    $form['flag'] = [
      '#type' => 'checkbox',
      '#title' => t('Required'),
      '#default_value' => $this->configuration['flag'],
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitConfigurationForm(array &$form, FormStateInterface $form_state): void {
    parent::submitConfigurationForm($form, $form_state);
    $this->configuration['flag'] = $form_state->getValue('flag');
  }

}
