<?php

namespace Drupal\eca\Plugin\ECA\Condition;

use Drupal\Core\Form\FormStateInterface;
use Drupal\eca\Annotation\EcaCondition;

/**
 * Plugin implementation of the ECA condition for a form field value.
 *
 * @EcaCondition(
 *   id = "form_field_value",
 *   label = "Form field value"
 * )
 */
class FormFieldValue extends BaseStringComparison {

  /**
   * {@inheritdoc}
   */
  protected function getFirstValue(): string {
    if (isset($this->arguments['form'], $this->arguments['form_state'])) {
      $form = $this->arguments['form'];
      $formState = $this->arguments['form_state'];
      if (is_array($form) && $formState instanceof FormStateInterface && $formState->hasValue($this->configuration['field_name'])) {
        return $formState->getValue($this->configuration['field_name']);
      }
    }
    return '';
  }

  /**
   * {@inheritdoc}
   */
  protected function getSecondValue(): string {
    return $this->configuration['field_value'];
  }

  /**
   * {@inheritdoc}
   */
  public function fields(): array {
    $fields = parent::fields();
    $fields[] = [
      'name' => 'field_name',
      'label' => 'Field name',
      'type' => 'String',
    ];
    $fields[] = [
      'name' => 'field_value',
      'label' => 'Value',
      'type' => 'String',
    ];
    return $fields;
  }

}
