<?php

namespace Drupal\eca\Plugin\ECA\Event;

use Drupal\eca\Annotation\EcaEvent;
use Drupal\eca\PluginEventBase;
use Drupal\Core\Config\ConfigCollectionInfo;
use Drupal\Core\Config\ConfigCrudEvent;
use Drupal\Core\Config\ConfigEvents;
use Drupal\Core\Config\ConfigImporterEvent;
use Drupal\Core\Config\ConfigRenameEvent;
use Drupal\Core\Config\Importer\MissingContentEvent;
use Drupal\Core\Config\StorageTransformEvent;

/**
 * Plugin implementation of the ECA Events for the config.
 *
 * @EcaEvent(
 *   id = "config",
 *   deriver = "Drupal\eca\Plugin\ECA\Event\ConfigEventDeriver"
 * )
 */
class ConfigEvent extends PluginEventBase {

  /**
   * @return array[]
   */
  public static function actions(): array {
    return [
      'delete' => [
        'label' => 'Delete config',
        'drupal_id' => ConfigEvents::DELETE,
        'drupal_event_class' => ConfigCrudEvent::class,
      ],
      'collection_info' => [
        'label' => 'Collect information on all config collections',
        'drupal_id' => ConfigEvents::COLLECTION_INFO,
        'drupal_event_class' => ConfigCollectionInfo::class,
      ],
      'import' => [
        'label' => 'Import config',
        'drupal_id' => ConfigEvents::IMPORT,
        'drupal_event_class' => ConfigImporterEvent::class,
      ],
      'import_missing_content' => [
        'label' => 'Import config but content missing',
        'drupal_id' => ConfigEvents::IMPORT_MISSING_CONTENT,
        'drupal_event_class' => MissingContentEvent::class,
      ],
      'import_validate' => [
        'label' => 'Import config validation',
        'drupal_id' => ConfigEvents::IMPORT_VALIDATE,
        'drupal_event_class' => ConfigImporterEvent::class,
      ],
      'rename' => [
        'label' => 'Rename config',
        'drupal_id' => ConfigEvents::RENAME,
        'drupal_event_class' => ConfigRenameEvent::class,
      ],
      'save' => [
        'label' => 'Save config',
        'drupal_id' => ConfigEvents::SAVE,
        'drupal_event_class' => ConfigCrudEvent::class,
      ],
      'storage_transform_export' => [
        'label' => 'Start config export',
        'drupal_id' => ConfigEvents::STORAGE_TRANSFORM_EXPORT,
        'drupal_event_class' => StorageTransformEvent::class,
      ],
      'storage_transform_import' => [
        'label' => 'Start config import',
        'drupal_id' => ConfigEvents::STORAGE_TRANSFORM_IMPORT,
        'drupal_event_class' => StorageTransformEvent::class,
      ],
    ];
  }

}
