<?php

namespace Drupal\eca;

use Drupal\Component\Plugin\PluginBase as DrupalPluginBase;
use Drupal\Core\Entity\EntityTypeBundleInfoInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Plugin\ContainerFactoryPluginInterface;
use Drupal\Core\Session\AccountProxyInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 *
 */
abstract class PluginBase extends DrupalPluginBase implements PluginInterface, ContainerFactoryPluginInterface {

  /**
   * @var array
   */
  protected array $arguments = [];

  /**
   * @var \Drupal\eca\ActionServices
   */
  protected ActionServices $actionServices;

  /**
   * @var \Drupal\eca\ModelerServices
   */
  protected ModelerServices $modelerServices;

  /**
   * @var \Drupal\eca\TokenServices
   */
  protected TokenServices $tokenServices;

  /**
   * @var \Drupal\Core\Session\AccountProxyInterface
   */
  protected AccountProxyInterface $currentUser;

  /**
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected EntityTypeManagerInterface $entityTypeManager;

  /**
   * @var \Drupal\Core\Entity\EntityTypeBundleInfoInterface
   */
  protected EntityTypeBundleInfoInterface $entityTypeBundleInfo;

  /**
   * @var \Symfony\Component\HttpFoundation\RequestStack
   */
  protected RequestStack $requestStack;

  /**
   * @param array $configuration
   * @param $plugin_id
   * @param $plugin_definition
   * @param \Drupal\eca\ActionServices $action_services
   * @param \Drupal\eca\ModelerServices $modeler_services
   * @param \Drupal\eca\TokenServices $token_services
   * @param \Drupal\Core\Session\AccountProxyInterface $current_user
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   * @param \Drupal\Core\Entity\EntityTypeBundleInfoInterface $entity_type_bundle_info
   * @param \Symfony\Component\HttpFoundation\RequestStack $requestStack
   */
  public function __construct(array $configuration, $plugin_id, $plugin_definition, ActionServices $action_services, ModelerServices $modeler_services, TokenServices $token_services, AccountProxyInterface $current_user, EntityTypeManagerInterface $entity_type_manager, EntityTypeBundleInfoInterface $entity_type_bundle_info, RequestStack $requestStack) {
    $this->actionServices = $action_services;
    $this->modelerServices = $modeler_services;
    $this->tokenServices = $token_services;
    $this->currentUser = $current_user;
    $this->entityTypeManager = $entity_type_manager;
    $this->entityTypeBundleInfo = $entity_type_bundle_info;
    $this->requestStack = $requestStack;
    parent::__construct($configuration, $plugin_id, $plugin_definition);
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container, array $configuration, $plugin_id, $plugin_definition): PluginBase {
    return new static(
      $configuration,
      $plugin_id,
      $plugin_definition,
      $container->get('eca.service.action'),
      $container->get('eca.service.modeler'),
      $container->get('eca.service.token'),
      $container->get('current_user'),
      $container->get('entity_type.manager'),
      $container->get('entity_type.bundle.info'),
      $container->get('request_stack')
    );
  }

  /**
   * {@inheritdoc}
   */
  final public function setArgument(string $key, $value): PluginInterface {
    $this->arguments[$key] = $value;
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  final public function setArguments(array $values): PluginInterface {
    foreach ($values as $key => $value) {
      $this->setArgument($key, $value);
    }
    return $this;
  }

  /**
   * {@inheritdoc}
   */
  final public function drupalId(): string {
    return $this->pluginDefinition['drupal_id'];
  }

  /**
   * {@inheritdoc}
   */
  public function fields(): array {
    return [];
  }

}
