<?php

namespace Drupal\eca;

use Drupal\eca\Entity\Eca;
use Drupal\eca\Entity\Objects\EcaObject;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Psr\Log\LoggerInterface;

class Processor {

  /**
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected EntityTypeManagerInterface $entityTypeManager;

  /**
   * @var \Psr\Log\LoggerInterface
   */
  protected LoggerInterface $logger;

  /**
   * Processor constructor.
   *
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entity_type_manager
   * @param \Psr\Log\LoggerInterface $logger
   */
  public function __construct(EntityTypeManagerInterface $entity_type_manager, LoggerInterface $logger) {
    $this->entityTypeManager = $entity_type_manager;
    $this->logger = $logger;
  }

  /**
   * @param \Symfony\Contracts\EventDispatcher\Event|\Symfony\Component\EventDispatcher\Event $event
   *
   * @throws \Drupal\Component\Plugin\Exception\InvalidPluginDefinitionException
   * @throws \Drupal\Component\Plugin\Exception\PluginNotFoundException
   */
  public function execute($event): void {
    /** @var \Drupal\eca\Entity\Eca $eca */
    foreach ($this->entityTypeManager->getStorage('eca')->loadMultiple() as $eca) {
      foreach ($eca->getUsedEvents() as $ecaEvent) {
        if ($ecaEvent->applies($event)) {
          $this->logger->info('Starting process ' . $ecaEvent->getId());
          $this->executeSuccessors($eca, $ecaEvent, $event);
        }
      }
    }
  }

  /**
   * @param \Drupal\eca\Entity\Eca $eca
   * @param \Drupal\eca\Entity\Objects\EcaObject $eca_object
   * @param \Symfony\Contracts\EventDispatcher\Event|\Symfony\Component\EventDispatcher\Event $event
   */
  protected function executeSuccessors(Eca $eca, EcaObject $eca_object, $event): void {
    $executedSuccssorIds = [];
    foreach ($eca->getSuccessors($eca_object) as $successor) {
      if (!in_array($successor->getId(), $executedSuccssorIds, TRUE)) {
        $this->logger->info('Executing ' . $successor->getId());
        if ($successor->execute($eca_object, $event)) {
          $executedSuccssorIds[] = $successor->getId();
          $this->executeSuccessors($eca, $successor, $event);
        }
      }
    }
  }

}
